local agent_helper = require("scripts/agent/agent_helper")

AgentAdapter = {
	is_init = false,
	login_callback = nil,
	force_logout = false,
	is_login_verify_ing = false,
	login_verify_url = "http://cls.mg02.q-dazzle.com/ay4/login_verify.php",
	pay_verify_url = "http://cls.mg02.q-dazzle.com/ay4/pay.php",
	uid = "",
}

--退出--按返回键，首先是来到这里的
function PlatformAdapter:OpenExitDialog()
	agent_helper:Exit(function(result)--调java
		if "true" == result then
			AdapterToLua:endGame()
		else
			local format = { title = "退出", message = "退出游戏?", positive = "确定", negative = "取消", }
			self:OpenAlertDialog(format, function (result) if "positive" == result then 
				AdapterToLua:endGame()
			end end)
		end
	end)
end

-- 初始化
function AgentAdapter:Init()

	if self.is_init then return end
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	self.is_init = true
	AgentMs:InitLocalPush()
	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "ay4"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return self:GetSpid().."_".. self.uid
end

--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[87]
end


--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "agentres/logo.png"
end

--获得loadingbg资源名
function AgentAdapter:GetLoadingbgName()
	return "agentres/loading_bg.jpg"
end



function AgentAdapter:Login(callback)
	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end
	self.login_callback = callback
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))--设置登录回调 

end

function AgentAdapter:OnClickBackLogin()
	agent_helper:Logout()
end

function AgentAdapter:OnClickRestartGame()
	agent_helper:Logout()
end


function AgentAdapter:LoginCallback(result)--登录后回调
	local json_obj = cjson.decode(result)
	local sdk = json_obj.sdk
	local uin = json_obj.uin
	local sess = json_obj.sess
	local app = json_obj.app

	local verify_callback = function(url, arg, data, size)
		self.is_login_verify_ing = false
		if size <= 0 then
			return
		end
		
		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			return
		end
	
		self.uid = ret_t.user.uid
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())

		agent_helper:ShowFloatButton()
	end

	self.is_login_verify_ing = true
	
	local real_url = string.format("%s?spid=%s&device=%s&sdk=%s&uin=%s&sess=%s&app=%s", self.login_verify_url, self:GetSpid(), tostring(PlatformAdapter.GetPhoneUniqueId()), sdk, uin, sess, app)
	Log("log_real_url====" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)

	return false
end

function AgentAdapter:LogoutCallback(result)--注销回调
	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()--跳到登录界面
	end
	return true
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)--购买
	if self.uid == "" then
		SysMsgCtrl.Instance:ErrorRemind("uid为空，请联系客服")
		return
	end
	local CpOrderId = server_id .. "_" .. GLOBAL_CONFIG.package_info.config.agent_id .. "_" .. self.uid .. "_" .. os.time()
	local param_obj = {}

	param_obj.unitPrice = amount * 10
	param_obj.itemName = amount * 10 .. "元宝"
	param_obj.count = 0.1 * 100
	param_obj.callBackInfo = CpOrderId
	param_obj.callBackUrl = self.pay_verify_url
	print(cjson.encode(param_obj))
	agent_helper:Pay(cjson.encode(param_obj), nil)

end

-- 创建角色上报
function AgentAdapter:ReportOnCreateRole(role_name)
	self:SubmitInfo(0)
end

function AgentAdapter:SubmitRoleInfoAck()
	self:SubmitInfo(1)
end

--  升级上报
function AgentAdapter:ReportOnRoleLevUp(role_id, role_name, role_level, zone_id, zone_name)
	self:SubmitInfo(2)
end


function AgentAdapter:SubmitInfo(typexx)
		local role_vo = GameVoManager.Instance:GetMainRoleVo()
		local user_vo = GameVoManager.Instance:GetUserVo()

		if role_vo ~= nil and user_vo ~= nil then
			local info = {}
			info.server_id = tostring(user_vo.plat_server_id)
			info.server_name = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
			info.role_name = role_vo.name
			info.role_id = tostring(role_vo.role_id)
			info.user_level = tostring(role_vo.level) or "0"
			info.vip_level = tostring(role_vo.vip_level) or "0"
			info.camp_name = Language.Common.CampName2[role_vo.camp or "无帮派"]	--阵营名字

			if RoleData.Instance and RoleData.Instance.role_info then
				info.gold = RoleData.Instance.role_info.gold or "0"
				info.party_name = RoleData.Instance.role_vo.guild_name or ""
			else
				info.gold = "0"
				info.party_name = ""
			end

			--上报创建角色时间
			if type == 0 then
				info.roleCTime = os.time()
			else
				info.roleCTime = tostring(role_vo.rol_ecreate_time) or "0"
			end
			info.roleLevelMTime = os.time()

			info.sub_type = tostring(typexx)
			PlatformBinder:JsonCall("send_user_info", cjson.encode(info));
		end
end

function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)
	Log("SubmitRoleData========");
		local role_vo = GameVoManager.Instance:GetMainRoleVo()
		local user_vo = GameVoManager.Instance:GetUserVo()

	if role_vo ~= nil and user_vo ~= nil then
			local info = {}
			info.server_id = tostring(user_vo.plat_server_id)
			info.server_name = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
			info.role_name = role_vo.name
			info.role_id = tostring(role_vo.role_id)
			info.user_level = tostring(role_vo.level) or "0"

	PlatformBinder:JsonCall("call_agent_submit_extend_data", cjson.encode(info))
	end
end

--是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end
